# Action Menu

You can configure some settings or launch some actions via ToolMate action menu.

![action_menu_0](https://github.com/eliranwong/letmedoit/assets/25262722/5519d920-94db-4575-b66f-0f4a7549544e)

# Launch Action Menu

Enter a blank entry '' in the ToolMate AI prompt to launch the action menu.

# Shortcut Keys

Some actions are assigned with shortcut keys, e.g. 'ctrl+n' to start a new start directly without launching the action menu.

For a full list of key bindings, press 'ctrl+k' or enter '.keys' in ToolMate prompt.

# Shortcut Entries

Shortcut entries that starts with a dot '.' trigger a quick action directly.

For example, entering '.new' to start a new chat, '.exit' to exit the current feature or the app, etc.

Press 'ctrl+k' and scroll to the bottom for a full list of quick actions, e.g.:

```
.new: start a new conversation ['c-n']
.open: open a saved conversation ['c-o']
.save: save current conversation
.saveas: save current conversation as ...
.export: export current conversation ['c-g']
.model: change AI backends and models
.apikeys: change API keys
.plugins: change plugins
.tools: change tool configurations
.managerisk: manage code execution risk
.context: change default context
.contextwindow: change context window size
.temperature: change output temperature
.maxtokens: change maximum output tokens
.maxmemorymatches: change maximum memory matches
.maxchatrecordmatches: change maximum chat record matches
.maxonlinesearches: change maximum online search results
.ipinfo: change ip information integration
.latestSearches: change online searches
.codedisplay: change code display
.pagerview: change pager view
.speechrecognition: change sppech recognition
.speechgeneration: change sppech generation
.read: read the last response
.toggledeveloper: toggle developer mode ['escape', 'd']
.togglemultiline: toggle multi-line input ['escape', 'l']
.togglemousesupport: toogle mouse support ['escape', 'm']
.toggletextbrightness: swap text brightness ['escape', 'b']
.togglewordwrap: toggle word wrap ['c-w']
.toggleinputimprovement: toggle input improvement ['escape', 'w']
.toggleinputaudio: toggle input audio ['escape', 'y']
.toggleoutputaudio: toggle output audio ['c-y']
.customtexteditor: change custom text editor
.editresponse: edit the last response ['escape', 'e']
.editconfigs: edit configuration settings
.autoupgrade: change automatic upgrade
.assistantname: change assistant name
.storagedirectory: change storage directory
.systemmessage: change system messages
.system: open system command prompt ['escape', 't']
.install: install python package
.keys: display key bindings ['c-k']
.help: open documentations
.donate: donate and support ToolMate AI
```

# Input suggestions

You don't need to memorise all actions, you may simply type a keyword and get some suggestions, e.g. type "model"

![action_menu_1](https://github.com/eliranwong/letmedoit/assets/25262722/0030aa56-8806-4ec7-b578-007202bc24ce)

# Filter the Action Menu

You can filter the action menu with a keyword.

e.g. to filter options related to 'model', enter

> .model

![action_menu_2](https://github.com/eliranwong/letmedoit/assets/25262722/4e552377-7568-49e6-88ad-c7c6dc3a984e)
